#
# spec file for package iwd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iwd
Version:        3.0
Release:        1.1
Summary:        Wireless daemon for Linux
License:        LGPL-2.1-or-later
URL:            https://git.kernel.org/pub/scm/network/wireless/iwd.git
Source:         https://kernel.org/pub/linux/network/wireless/%{name}-%{version}.tar.xz
Source1:        https://kernel.org/pub/linux/network/wireless/%{name}-%{version}.tar.sign
# https://kernel.org/doc/wot/holtmann.html
Source2:        %{name}.keyring
# needed for the tests to generate certificates
# BuildRequires:  openssl
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ell) >= 0.69
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}

%description
The iNet Wireless Daemon (iwd) project provides a wireless
connectivity solution. It attempts to optimise resource utilisation
of storage, runtime memory and link-time costs. It utilises the
features provided by the Linux kernel.

%prep
%autosetup -p1

%build
%configure \
    --libexecdir=%{_libexecdir}/%{name} \
    --enable-external-ell \
    %{nil}
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_sbindir}/
ln -s service %{buildroot}%{_sbindir}/rc%{name}

# kernel-obs-build is missing af_alg.ko currently and the tests
# use -Wl,--wrap, incompatible with LTO (https://gcc.gnu.org/bugzilla/show_bug.cgi?id=88643)
#%%check
#%%make_build check

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/iwctl
%{_bindir}/iwmon
%{_sbindir}/rc%{name}
%{_libexecdir}/%{name}/
%dir %{_prefix}/lib/modules-load.d/
%{_prefix}/lib/modules-load.d/pkcs8.conf
%dir %{_prefix}/lib/systemd/network
%{_prefix}/lib/systemd/network/80-iwd.link
%{_unitdir}/%{name}.service
%dir %{_datadir}/dbus-1/system.d/
%{_datadir}/dbus-1/system.d/%{name}*.conf
%{_datadir}/dbus-1/system-services/*%{name}.service
%{_mandir}/man1/iwctl.1%{?ext_man}
%{_mandir}/man1/iwmon.1%{?ext_man}
%{_mandir}/man5/iwd.config.5%{?ext_man}
%{_mandir}/man5/iwd.network.5%{?ext_man}
%{_mandir}/man5/iwd.ap.5%{?ext_man}
%{_mandir}/man7/iwd.debug.7%{?ext_man}
%{_mandir}/man8/iwd.8%{?ext_man}

%changelog
* Tue Oct 29 2024 Luigi Baldoni <aloisio@gmx.com>
  ver 3.0:
  * Fix issue with handling alpha2 code for United Kingdom.
  * Fix issue with handling empty TX/RX bitrate attributes.
  * Fix issue with handling RSSI polling fallback workaround.
  * Fix issue with handling harmless cloned information elements.
  * Add experimental support for External Authentication feature.
* Tue Oct  1 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.22
  * Fix issue with handling the Affinities property.
  * Fix issue with handling ConnectedAccessPoint signal when
    roaming.
  version 2.21:
  * Fix issue with pending scan requests after regdom update.
  * Fix issue with handling the rearming of the roaming timeout.
  * Fix issue with survey request and externally triggered scans.
  * Fix issue with RSSI fallback when setting CQM threshold
    fails.
  * Fix issue with FT-over-Air without offchannel support.
  * Add support for per station Affinities property.
  version 2.20:
  * Fix issue with PKEX timeout and number of frequencies used.
  * Fix issue with handling logic for handshake failures.
  * Fix issue with handling ConnectedAccessPoint signal.
* Tue Jul  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.19:
  * Fix issue with handling flush flag for external scans.
  * Fix issue with handling SNR calculation in ranking.
* Fri Jun  7 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.18
  * Fix issue with handling BSS with invalid HE capabilities.
  * Fix issue with neighbor reports with invalid country codes.
  * Fix issue with EAP-TTLS Start packets with L flag set.
  * Add support for enabling SAE for AP mode operation.
* Mon Apr  1 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.17
  * Fix issue with handling deauthenticate on disconnect.
  * Fix issue with handling of rate estimation errors.
  * Fix issue with handling EAPOL frame listeners.
* Sat Mar 23 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.16 (bsc#1221018, CVE-2024-28084):
  * Fix issue with uninitialized variable and DPP encrypt.
  * Fix issue with Access Point mode and ATTR_MAC validation.
  * Fix issue with Access Point mode and frequency attributes.
  * Fix issue with P2P and handling client info description.
  * Fix issue with P2P and handling parsing of service info.
  * Fix issue with netconfig and handling domain list.
  * Add support for forcing a default ECC group.
  version 2.15:
  * Fix issue with notice events for connection timeouts.
  * Fix issue with reason code and deauthenticate event.
  * Fix issue with handling basename() functionality.
* Sat Feb 17 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.14
  * Fix issue with accepting PTK 4/4 after receiving PTK 2/4.
  * Fix issue with frequency limit for quick scans.
  * Fix issue with limiting DHCPv4 attempts.
* Fri Jan 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.13 [boo#1218410]
  * Fix issue with handling netconfig and roaming conditions.
  * Fix issue with logging requirement for CMD_EXTERNAL_AUTH.
  * Fix issue with using OpenSSL 3.2 installations.
* Sun Dec 31 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.12 [boo#1218410]
  * add support for SAE password identifiers
* Wed Dec 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.11 [boo#1218410]
  * Fix issue with handling iovecs with multiple IEs, handling SAE
    password identifiers, and handling agent release method calls.
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9:
  * Fix issue with handling certain FT failures.
  * Fix issue with handling user-disabled bands.
  * Fix issue with handling roam on beacon loss event.
  * Add support for PKEX configurator.
  * Add support for PKEX enrollee.
* Tue Aug 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.8
  * Fix issue with handling OWE AKM in association reply.
* Sat Jul  8 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.7
  * Fix issue with handling FT-8021X and SHA256 PMKID derivation.
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6:
  * Add support for setting driver specific quirks.
  * Add support for disabling power saving mode.
* Mon Jun 19 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5:
  * Fix issue with HT40+/- checks when creating chandef.
  * Fix issue with handling support for FT-8021X-SHA384.
  * Fix issue with handling secure bit check in handshake 1/4.
  * Fix issue with allowing roaming before netconfig finishes.
  * Fix issue with double free when disconnecting during FT.
* Wed May 17 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.4:
  * Fix issue with FT-over-Air and same channel operation.
  * Fix issue with AP mode and missing support for GTK.
  * Fix issue with AP mode and channel switch event.
  * Fix issue with SSID string conversion handling.
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3 (bsc#1208267):
  * Fix issue with length calculation for WMM IE.
  * Fix issue with channel number allocation off-by-one.
  * Fix issue with cached session when TLS phase2 fails.
  * Add support for FastReauthentication setting for EAP-TLS.
* Wed Jan 25 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 2.2:
  * Fix issue with handling FT and multiple roaming scans.
  * Fix issue with handling multiple wiphy registrations.
  * Fix issue with with EAP-PEAP session resumption.
  * Add support for using PTK rekeying in AP mode.
  * Add support for setting country IE in AP mode.
  * Add support for setting WMM parameter IE in AP mode.
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1:
  * Fix issue with handling FT-over-DS action.
  * Fix issue with handling scan and 6 GHz support check.
  * Fix issue with handling when periodic scans get aborted.
  * Add support for using 5 GHz frequencies in AP mode.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0:
  * Fix issue with handling P2P and limiting ciphers to CCMP.
  * Fix issue with scanning before forced roaming action.
  * Fix issue with provided scan frequencies from RRM.
  * Fix issue with handling Michael MIC failure message.
  * Fix issue with handling timestamp size in MPDU frames.
  * Fix issue with handling enablement of OCVC for FT AKMs.
  * Fix issue with handling FT work as highest priority.
  * Fix issue with handling roaming events and Multi-BSS.
  * Add support for utilizing roaming candidates list.
  * Add support for utilizing TLS session caching.
  * Add support for ciphers with 256 bits key size.
  * Add support for Access Point mode with legacy TKIP.
  * Add support for MAC address changes while powered.
  * Add support for IPv4 and IPv6 network configuration.
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 1.30:
  * Fix issue with handling OWE if buggy AP is detected.
  * Fix issue with handling quick scan and enabling 6GHz.
  * Fix issue with handling tags for extended IEs.
  * Add support for handling HE capabilities.
  * Add support for handling regulatory domain changes.
  * Add support for handling netdev packet loss events.
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29:
  * Fix issue with handling EAP-Success message.
  * Fix issue with handling secure setting and EAPoL.
  * Add support for DeviceProvisioning API properties.
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.28:
  * Fix issue with handling invalid EAPoL frames.
  * Fix issue with handling unexpectedly unencrypted EAP frames.
  * Fix issue with handling AlwaysRandomizeAddress/AddressOverride.
  * Fix issue with handling initial signal level notification.
  * Fix issue with handling sorting of scan requests.
  * Fix issue with handling frame type check in FT.
* Tue May 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.27:
  * Fix issue with hidden networks on connection error.
  * Fix issue with directed roams if already trying to roam.
  * Fix issue with checking for connected in FT frame event.
* Tue Apr 19 2022 Fabian Vogt <fvogt@suse.com>
- Update to 1.26:
  * Fix issue with handling BSS that changed frequency.
  * Fix issue with handling frequencies in neighbor report.
  * Fix issue with operating classes for 802.11ax standard.
  * Fix issue with enforcing of MFPR for 6 GHz frequencies.
  * Add support for band defined in the WiFi 6E amendment.
  * Add support for scanning while in AP mode.
- Drop unnecessary _service file
- Be more detailed about why %%check fails
- Down modules-load.d directory to fix build on TW
* Fri Feb 25 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.25:
  * Fix issue with handling abort of periodic scans.
  * Fix issue with handling connection when link goes down.
  * Fix issue with handling operating channel information.
  * Add support for encrypted network profile storage.
  * Add support for DPP initiating as a configurator.
  * Fix issue with handshake and missing rekeying support.
  * Fix issue with BSS ranking and zero signal strength.
  * Fix issue with setting OWE IE length correctly.
  * Fix issue with handling handshake offloading.
  * Fix issue with at_console and D-Bus policy.
* Thu Jan 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix required version of pkgconfig(ewl): configure checks for
  version 0.48 as min required version.
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to v1.22:
  * Fix issue with handling periodic scanning.
  * Fix issue with handling scanning completion.
  * Fix issue with handling scanning for OWE auto-connect.
  * Add support for additional DPP features.
  * Fix issue with handling disconnect events issued by AP.
  * Add experimental support for DPP feature.
* Fri Nov 26 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to v1.20
  * Fix issue with handling Hotspot 2.0 requirements.
  * Add support for evict_nocarrier setting during roaming.
  * Add support for experimental NetworkConfigurationAgent API.
* Mon Nov  8 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to v1.19
  * Fix issue with handling OCV if offloading is supported.
  * Fix issue with handling SA Query on channel switch event.
  * Fix issue with starting FT-over-DS actions after roaming.
  * Add support for OWE transition networks.
  * Add support for extended key IDs.
* Sun Sep 19 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to v1.18
  * Add support for Access Point FILS IP Address Assignment IE.
  * Add support for P2P GO-side 4-way handshake IP allocation.
  * Add support for forcing SAE group 19 if BSS requires it.
  * Fix issue with handling faulty SAE duplicate commits.
* Tue Sep  7 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to v1.17
  * Fix issue with sending additional and vendor IEs.
  * Fix issue with IE ordering for 802.11-2020 support.
  * Fix issue with frequency update on channel switch events.
  * Fix issue with drivers and handling of IF_OPER_UP setting.
* Mon Aug 30 2021 Malte Ohmstede <malte.ohmstede@gmail.com>
- update to v1.16
  ver 1.16:
  * Fix issue with writing provisioning files with a passphrase.
  * Add support for Authenticator & Supplicant RSN Extension elements.
  * Add support for handling Transition Disable info.
  * Add support for SAE Hash-to-Element feature.
  ver 1.15:
  * Add support for FT-over-DS procedure with multiple BSS.
  * Add support for estimation of VHT RX data rate.
  * Add support for exporting Daemon information.
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- update to 1.14:
  * Fix issue with scanning property and quick scan cancellation.
  * Fix issue with handling authentication timeouts from SAE.
  * Fix issue with handling association timeouts and retries.
  * Fix issue with handling roaming frequencies after roaming.
  * Fix issue with requesting neighbor report after roaming.
  * Add support for handling PSK offload connections.
  * Fix issue with EAPoL protocol version 2010 handling.
  * Fix issue with authenticator method logic handling.
  * Fix issue with getting scan results from firmware.
  * Add support for handling SAE offload connections.
  * Add support for roaming with FullMAC devices.
* Thu Feb 25 2021 Maciej Borzecki <maciek.borzecki@gmail.com>
- Update to version 1.12:
  * Fix issue with handling retry roaming without higher RSSI.
  * Fix issue with WPA3, OWE and FILS authentication handling.
  * Fix issue with handling locally generated deauth frames.
  * Fix issue with quick scanning and connect interaction.
  * Add support for diagnostic D-Bus interfaces.
* Sun Jan 10 2021 Maciej Borzecki <maciek.borzecki@gmail.com>
- Update to version 1.11:
  * Add support for ACD client for static configuration.
  * Add support for intelligent scan of all frequencies.
  * Add support for DHCP v6 configuration.
  * Add support for DHCP server operation with AP mode.
  * Add support for IP allocation during the 4-Way Handshake.
  * Add support for P2P Group-owner handling.
* Wed Sep 30 2020 Ava Lon <minava@t-online.de>
- Update to version 1.9:
  * Fix issue with WPA3 connections in transition mode.
  * Fix issue with handling roaming attempt failures.
  * Add support for radio management work queue.
  * Add support P2P service manager interface.
  * Add support for WiFi Display client API.
* Tue Aug 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix wrong usage of %%{_libexecdir} for systemd owned directories
  below %%{_prefix}/lib.
* Wed Jun 17 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.8:
  * Fix an issue with handling FT AKMs when not supported.
  * Fix an issue with handling FILS and RSNE in authenticate.
  * Fix an issue with handling auto-connection and quick scan.
  * Fix an issue with sending multiple scan requests.
  * Add support for a P2P feature and API.
  Wed 15 Apr 08:46:02 CEST 2020 - Harry ten Berge <htenberge@gmail.com>
- ver 1.7:
  * Fix issue with APs that send IGTK falsely in big endian.
  * Fix issue with setting linkmode & operstate for open networks.
  Thu 26 Mar 10:18:24 CET 2020 - Harry ten Berge <htenberge@gmail.com>
- ver 1.6:
  * Fix issue with handling missing AP stop events.
  * Fix issue with handling out-of-order disconnect events.
  * Fix issue with handling missing auth/assoc support.
  * Fix issue with handling omitted EAP-TLS-CACert.
  * Fix issue with handling OWE PTK derivation.
  * Add support for internal frame exchange API.
  * Add support for MAC randomization and override.
  * Add support for per-network MAC addresses.
  Mon 10 Feb 10:02:45 CET 2020 - Harry ten Berge <htenberge@gmail.com>
- ver 1.5:
  * Fix issue with handling missing NEW_WIPHY events.
  * Fix issue with interface creation and NEW_WIPHY events.
  * Fix issue with handling LastConnectedTime property change.
  * Fix issue with PEAPv0 interoperability with Windows.
* Fri Jan  3 2020 Harry ten Berge <htenberge@gmail.com>
- ver 1.4:
  * Fix issue with handling Crypto-Binding and invalid MACs.
  * Fix issue with handling change station error results.
  * Fix issue with handling DNS resolving installations.
* Tue Dec 17 2019 Harry ten Berge <htenberge@gmail.com>
- ver 1.3:
  * Fix issue with handling EAP-GTC and password requests.
  * Fix issue with handling Crypto-Binding TLV for PEAPv0.
  * Fix issue with handling key installation and PEAP Phase 2.
  * Fix issue with handling externally triggered scan requests.
  * Fix issue with handling RCPI calculation for RRM requests.
- ver 1.2:
  * Fix issue with handling scan requests while connecting.
  * Fix issue with handling scan duration for RRM requests.
  * Fix issue with handling parent TSF value for RRM requests.
- ver 1.1:
  * Fix issue with simple configuration support checks.
  * Fix issue with handling TLS tunnel and PEAPv0.
  * Add support for radio resource management.
* Wed Nov 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Disable testsuite and openssl BuildRequires, it fails on the obs,
  but leave them behind as the tests works fine on a checkout.
- Modernize spec.
* Fri Nov  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Execute testsuite
* Wed Oct 30 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0:
  * Add support for stable D-Bus interfaces.
  * Add support for network configuration documentation.
* Sun Oct 27 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.23:
  * Fix issue with strict certificate chain checks.
  * Fix issue with parsing RSNE_ADVANCE information.
  * Fix issue with parsing RSN information for WPA1.
  * Fix issue with logic error in scan frequency validation.
  * Fix issue with integer overflow and authentication frames.
  * Add support for installing various manual pages.
- ver 0.22:
  * Fix issue with hotplug and device capability detection.
  * Add support for IPv6 network configuration handling.
  * Add support for embedding certificates in profiles.
* Fri Sep 20 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.21:
  * Fix issue with cleartext ACK and tunneled EAP-Success.
  * Fix issue with setting bits in extended capabilities.
  * Fix issue with WPA-1 information element parsing.
  * Add support for handling QoS Map IE and frames.
  * Add support for STATE_DIRECTORY environment.
  * Add support for CONFIGURATION_DIRECTORY environment.
- ver 0.20:
  * Add support for adding Extended Capabilities bits.
  * Add support for ServerDomainMask configuration option.
* Mon Aug 12 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.19:
  * Add support for Hotspot 2.0 functionality.
  * Add support for FILS Fast Transition feature.
  * Add support for network configuration handling.
  * Add support for resolution services framework.
* Mon May 27 2019 Xaver Hellauer <xaver@hellauer.bayern>
- ver 0.18:
  * Fix issue with handling stale scan results.
  * Fix issue with handling OWE group renegotiation.
  * Fix issue with handshake failures on FT-PSK.
  * Add support for FILS (Fast Initial Link Setup).
- ver 0.17:
  * Fix issue with handling association failure path.
  * Fix issue with handling checks for valid ECC point/scalar.
  * Fix issue with handling potential infinite loop and SAE.
  * Fix issue with handling randomization for passive scans.
  * Add support for randomization of SN for probe requests.
  * Add support for handling the FILS cipher suites.
  * Add support for ERP key caching feature.
* Fri Apr  5 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.16 (changes since 0.13):
  * Add support for tunneled MSCHAPv2 authentication.
  * Fix an issue with handling RSSI thresholds.
  * Fix an issue with handling abort for a connection.
  * Fix an issue with stopping Access Point operation.
  * Add support for individual BSS blacklisting.
  * Add support for utilising MAC randomisation.
  * Add support for utilising different key lengths.
  * Add support for 16, 24 and 32 byte MIC lengths.
  * Add support for handling driver rekying feature.
  * Add missing pkcs8.conf for module loading.
* Thu Dec 13 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid using bundled copy of ell
* Thu Dec 13 2018 mardnh@gmx.de
- Update to version 0.13:
  * Fix issue with WSC interface runtime handling.
  * Add support for Opportunistic Wireless Encryption.
  * Add support for common EAP-TLS framework.
* Sat Nov 17 2018 sean@suspend.net
- Update to version 0.12:
  * build: require at least version 0.15 when building ext ELL
  * network: simplify is_rsn logic
  * network: Check autoconnectable as the first condition
  * network: Introduce __bss_is_sae
  * scan: make scan_bss_get_rsn_info const correct
  * network: fix 8021x autoconnect
  * station: only set 8021x networks
  * client: fix mem leak
* Tue Oct 23 2018 sean@suspend.net
- Update to version 0.10:
  * Fix issue with Ethernet authentication packet handling
  * Fix issue with ad-hoc network scan results in station mode
  * Fix issue with cancellation of ongoing rekey offload
  * Add support for setting per-mac GTK credentials
  * Add support for using external Embedded Linux library
* Tue Oct  9 2018 sor.alexei@meowr.ru
- Update to version 0.9:
  * Fix an issue with handling EAP-WSC passwords.
  * Add support for TTLS-CHAP and TTLS-PAP.
  * Add support for handling FT over SAE.
* Mon Sep 24 2018 sor.alexei@meowr.ru
- Update to version 0.8:
  * Fix issue with handling EAP_CACHE_NEVER secret types.
  * Fix issue with redundant usage of the L flag and PEAP.
  * Fix issue with EAP type 33 as termination mechanism for PEAPv1.
  * Add initial version of Ethernet authentication daemon.
  * Add support for Station mode interface.
* Tue Sep 11 2018 astieger@suse.com
- add upstream signing key and validate source signature
* Tue Sep 11 2018 sor.alexei@meowr.ru
- Update to version 0.7 (changes since 0.4):
  * Fix an issue with EAPoL handling and Ad-Hoc networks.
  * Add support for using agent with EAP-GTC methods.
  * Add support for improved Known Networks management.
  * Add support for Simultaneous Authentication of Equals.
  * Add support for exposing supported modes of operation.
  * Add support for D-Bus auto-activation via systemd.
  * Fix an issue with synching the PSK on first connection.
  * Fix an issue with unnecessary known object removal events.
  * Fix an issue with hard coded peer address and SAE networks.
  * Fix an issue with raw passphrase requirement and SAE networks.
  * Fix an issue with differentiating authenticator and supplicant.
  * Fix an issue with timestamps comparison of known networks.
  * Fix an issue with handling cancellation of power callbacks.
  * Fix an issue with honouring auto-connect setting on power up.
  * Fix an issue with a crash during operstate callbacks.
* Fri Jul 27 2018 sor.alexei@meowr.ru
- Update to version 0.4:
  * Fix an issue with handling all zero PMKID.
  * Fix an issue with handling PEAP servers and M bit requirement.
  * Fix an issue with handling MS-CHAP v2 and uninitialised memory.
  * Fix an issue with handling a memory leak and aborting
    connections.
  * Fix an issue with handling a memory leak and PSK configuration.
  * Fix an issue with handling a not yet running D-Bus daemon.
  * Add support for advanced scanning of hidden networks.
  * Add support for MAC address randomisation.
  * Add support for the Ad-Hoc network interface.
  * Add support for the Access Point interface.
* Fri Jul 27 2018 jengelh@inai.de
- Trim marketing wording and false statements from description.
* Sat Jun 30 2018 sor.alexei@meowr.ru
- Initial package.
